@@ -59,7 +59,7 @@ private:
 
 	void on_mouse_up(const CL_Key &key);
 
-	void on_mouse_move(CL_Component *component, int x, int y);
+	void on_mouse_move(int x, int y);
 
 	void on_button_sketch(Sketch *sketch);
 	std::list<CL_Slot> slots_button_sketch;
