@@ -24,10 +24,7 @@ InputLabel::~InputLabel()
 
 // implementation:
 
-void InputLabel::on_key_down(
-	CL_Component *comp,
-	CL_InputDevice *input,
-	const CL_Key &key)
+void InputLabel::on_key_down(const CL_Key &key)
 {
 	if (key.id == CL_KEY_ENTER) sig_enter();
 	if (key.ascii > 0) set_text(get_text() + std::string((char)key.ascii, 1));
