@@ -24,7 +24,7 @@ public:
 
 	// implementation:
 private:
-	void on_key_down(CL_Component *comp, CL_InputDevice *input, const CL_Key &key);
+	void on_key_down(const CL_Key &key);
 	CL_Slot slot_key_down;
 };
 
