@@ -6,7 +6,7 @@
 #include <ClanLib/GUI/listbox.h>
 #include <ClanLib/GUI/label.h>
 #include <ClanLib/GUI/inputbox.h>
-#include <ClanLib/GUI/combobox.h>
+//#include <ClanLib/GUI/combobox.h>
 
 class MainFrame;
 class Document;
@@ -30,7 +30,7 @@ public:
 
 	CL_InputBox value_inputbox;
 
-	CL_ComboBox value_combobox;
+//	CL_ComboBox value_combobox;
 
 //!Operations:
 public:
