@@ -30,11 +30,11 @@ public:
 
 //!Implementation:
 private:
-	std::map<ComponentNode *, CL_TreeView_Node *> tree_nodes;
+	std::map<ComponentNode *, CL_TreeNode *> tree_nodes;
 
 	void on_resize(int old_width, int old_height);
 
-	void on_tree_selection_changed(const CL_TreeView_Node &node);
+	void on_tree_selection_changed(const CL_TreeNode &node);
 
 	void on_node_added(ComponentNode *node);
 
