@@ -1,4 +1,3 @@
-#include <iostream.h>
 #include <ClanLib/core.h>
 #include <ClanLib/gui.h>
 #include <ClanLib/application.h>
@@ -9,10 +8,7 @@ class ButtonTest : public CL_ClanApplication
 public:
 	char *get_title() { return "ButtonTest"; }
 
-	CL_ResourceManager *resources;
-	CL_StyleManager *style;
 	CL_ComponentManager *manager;
-	CL_GUIManager *gui;
 	
 	int main(int argc, char** argv)
 	{
@@ -27,24 +23,21 @@ public:
 			CL_SetupDisplay::init();
 			CL_Display::set_videomode(640,480,16, false);
 
-			resources = new CL_ResourceManager("resources.scr", false);
-			style = new CL_StyleManager_Default(resources);
-			gui = new CL_GUIManager(style);
-			manager = CL_ComponentManager::create("buttontest.gui", false, style,gui);
-			
+			CL_ResourceManager resources("../GUIThemeDefault/gui.scr", false);
+			CL_StyleManager_Default style(&resources);
+			CL_GUIManager gui(&style);
+
+			manager = CL_ComponentManager::create("buttontest.gui", false, &style, &gui);
 			
 			while (!CL_Keyboard::get_keycode(CL_KEY_ESCAPE))
 			{
 				CL_Display::clear_display(0.60f, 0.60f, 0.60f);
-				gui->show();
+				gui.show();
 				CL_System::keep_alive();
 				CL_Display::flip_display();
 			}
 			
-			delete gui;
 			delete manager;
-			delete style;
-			delete resources;
 
 			CL_SetupDisplay::deinit();
 			CL_SetupGUI::deinit();
@@ -53,14 +46,10 @@ public:
 		catch (CL_Error e)
 		{
 			std::cout << e.message.c_str() << std::endl;
-		}
-		catch (...)
-		{
-			std::cout << "Ugga" << std::endl;
-		}
 
-		// Display console close message and wait for a key
-		console.display_close_message();
+			// Display console close message and wait for a key
+			console.display_close_message();
+		}
 
 		return 0;
 	}
