@@ -1,7 +1,7 @@
 -- Example 2
 -- Lenny Palozzi
 
-CL_Display:set_videomode(640, 480, 16)
+CL_Display:set_videomode(640, 480, 16,0)
 
 mx = CL_Mouse:get_x()
 my = CL_Mouse:get_y()
