@@ -1,38 +1,37 @@
 /*
 	The minimum requirements needed by every ClanLib application.
 
-	note that the try/catch is not required but should be added 
+	Note that the try/catch is not required but should be added 
 	to every ClanLib application.
 */
 
 #include <ClanLib/core.h>
+#include <ClanLib/application.h>
 
 class MinimumApp : public CL_ClanApplication
 {
 public:
 	virtual char *get_title() { return "Minimum application"; }
 
-	virtual void init_modules()
-	{
-		CL_SetupCore::init();
-	}
-
-	virtual void deinit_modules()
-	{
-		CL_SetupCore::deinit();
-	}
-
 	virtual int main(int, char **)
 	{
+		// Create a console window for text-output if not available
+		CL_ConsoleWindow console("Console");
+		console.redirect_stdio();
+
 		try
 		{
-			std::cout << "Hello World" << std::endl;
+		 	CL_SetupCore::init();
+	 		CL_SetupCore::deinit();
 		}
 		catch (CL_Error err)
 		{
 			std::cout << "Exception caught: " << err.message.c_str() << std::endl;
-			return -1;
+
+			// Display console close message and wait for a key
+			console.display_close_message();
 		}
+
 		return 0;
 	}
 } app;
