@@ -3,22 +3,13 @@
 #define header_netchannel_demo
 
 #include <ClanLib/core.h>
+#include <ClanLib/display.h>
+#include <ClanLib/network.h>
+#include <ClanLib/application.h>
 
 class NetChannelDemo : public CL_ClanApplication
 {
 public:
-	virtual void init_modules()
-	{
-		CL_SetupCore::init();
-		CL_SetupCore::init_network();
-	}
-
-	virtual void deinit_modules()
-	{
-		CL_SetupCore::deinit_network();
-		CL_SetupCore::deinit();
-	}
-
 	virtual char *get_title();
 	virtual int main(int argc, char **argv);
 	
