@@ -63,7 +63,7 @@ public:
 				// Draw the surface:
 				surface->put_screen(0, 0);
 				
-				//improve response
+				// Improve response
 				CL_System::sleep(10);
 				
 				// Flip front and backbuffer. This makes the changes visible:
@@ -73,6 +73,8 @@ public:
 				CL_System::keep_alive();
 			}
 
+			delete surface;
+
 			CL_SetupDisplay::deinit();
 			CL_SetupCore::deinit();
 		}
