@@ -1,5 +1,5 @@
 /*
-	$Id: inputsource_provider.h,v 1.9 2001/12/11 20:44:18 mbn Exp $
+	$Id: inputsource_provider.h,v 1.10 2002/02/28 22:12:56 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -54,6 +54,10 @@ public:
 	//: Returns a copy of the current provider.
 	//- Returns - The copy of the inputsource provider.
 	virtual CL_InputSourceProvider *clone() = 0;
+
+	//: Get full path to source:
+	virtual std::string get_path(const std::string &filename) = 0;
+
 };
 
 #endif
