@@ -1,5 +1,5 @@
 /*
-	$Id: cl_vector.h,v 1.9 2001/09/22 15:52:11 plasmoid Exp $
+	$Id: cl_vector.h,v 1.10 2002/06/08 20:50:33 grumbel Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -127,7 +127,9 @@ public:
 	float& operator [] (int n);
 	
 	//: cout's the x,y,z ordinates (meant for debugging)
-	friend std::ostream& operator << (std::ostream&, CL_Vector& v);
+	friend std::ostream& operator << (std::ostream&, const CL_Vector& v);
 };
 
+std::ostream& operator << (std::ostream& os, const CL_Vector& v);
+
 #endif
