@@ -1,5 +1,5 @@
 /*
-	$Id: resourceoption.h,v 1.11 2001/09/24 04:51:12 plasmoid Exp $
+	$Id: resourceoption.h,v 1.13 2002/02/25 21:23:17 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -51,6 +51,20 @@ public:
 	  num_vals = 0;
 	}
 
+	CL_ResourceOption(const CL_ResourceOption &other)
+	{
+		num_vals = other.num_vals;
+		name = other.name;
+		if(num_vals)
+		{
+			std::vector<std::string>::const_iterator it;
+			for(it = other.values.begin(); it != other.values.end(); ++it)
+			{
+				values.push_back(*it);
+			}
+		}
+	}
+
 //! Attributes:
 public:
 	//: Get Name
@@ -68,6 +82,20 @@ public:
 
 //! Operations:
 public:
+	void operator =( const CL_ResourceOption &other)
+	{
+		num_vals = other.num_vals;
+		name = other.name;
+		if(num_vals)
+		{
+			std::vector<std::string>::const_iterator it;
+			for(it = other.values.begin(); it != other.values.end(); ++it)
+			{
+				values.push_back(*it);
+			}
+		}
+	}
+
 	//: Add a Value
 	//- value - the string value to add
 	//- Returns - the index of the added value
