@@ -1,5 +1,5 @@
 /*
-	$Id: clanstring.h,v 1.30 2001/11/02 02:24:08 plasmoid Exp $
+	$Id: clanstring.h,v 1.33 2002/02/20 08:06:28 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -44,7 +44,6 @@
 #define NEED_FCVT
 #endif
 
-
 #ifdef NEED_FCVT
 extern char *fcvt (double, int, int *, int *);
 #endif
@@ -346,7 +345,7 @@ public:
 	//: Get Length
 	int get_length()
 	{
-		return str.length();
+		return (int)str.length();
 	}
 
 	//: Get As int
@@ -358,7 +357,7 @@ public:
 	//: Get As Float
 	float get_as_float()
 	{
-		return atof(str.c_str());
+		return (float)atof(str.c_str());
 	}
 
 	//: Get Word
@@ -446,10 +445,10 @@ public:
 	//: Find Last
 	int find_last(char character) const
 	{
-		const char *temp=str.c_str();
-		int start_pos=str.length();
-		for(int i=start_pos;i;i--)
-			if(*(temp+i)==character)
+		const char *temp = str.c_str();
+		int start_pos = (int)str.length();
+		for(int i = start_pos; i; i--)
+			if(*(temp+i) == character)
 				return i;
 		return -1;
 	}
@@ -475,7 +474,7 @@ public:
 	//: To Lower
 	void to_lower()
 	{
-		int len = str.length();
+		int len = (int)str.length();
 		for (int i=0; i<len; i++)
 		{
 			str[i] = tolower(str[i]);
@@ -485,7 +484,7 @@ public:
 	//: To Upper
 	void to_upper()
 	{
-		int len = str.length();
+		int len = (int)str.length();
 		for (int i=0; i<len; i++)
 		{
 			str[i] = toupper(str[i]);
@@ -501,10 +500,10 @@ private:
 		sprintf(buf, "%d", number);
 
 		int len=0;
-		if (prefix!=NULL) len=strlen(prefix);
+		if (prefix != NULL) len = (int)strlen(prefix);
 
-		char *text=new char[len+strlen(buf)+1];
-		if (prefix!=NULL)
+		char *text = new char[len + strlen(buf) + 1];
+		if (prefix != NULL)
 		{
 			strcpy(text, prefix);
 			strcat(text, buf);
@@ -522,10 +521,10 @@ private:
 	std::string float_to_string(const char *prefix, const float _float_number)
 	{
 		char buf[25];
-		buf[0]=0;
+		buf[0] = 0;
 
 		int decimal, sign;
-		int precision=4;
+		int precision = 4;
 		char temp;
 
 		float float_number = _float_number;
@@ -540,7 +539,7 @@ private:
 		strcpy(float_buffer, _float_buffer);
 
 		if (sign) strcpy(buf, "-");
-		if (decimal<=0)
+		if (decimal <= 0)
 		{
 			strcat(buf, "0.");
 			strcat(buf, float_buffer);
@@ -548,19 +547,19 @@ private:
 	    else
 		{
 			temp=float_buffer[decimal];
-			float_buffer[decimal]=0;
+			float_buffer[decimal] = 0;
 			strcat(buf, float_buffer);
-			float_buffer[decimal]=temp;
+			float_buffer[decimal] = temp;
 
 			strcat(buf, ".");
 			strcat(buf, &float_buffer[decimal]);
 		}
     
 		int len=0;
-		if (prefix!=NULL) len=strlen(prefix);
+		if (prefix != NULL) len = (int)strlen(prefix);
 
-		char *text=new char[len+strlen(buf)+1];
-		if (prefix!=NULL)
+		char *text = new char[len + strlen(buf) + 1];
+		if (prefix != NULL)
 		{
 			strcpy(text, prefix);
 			strcat(text, buf);
@@ -575,15 +574,15 @@ private:
 	std::string append_string(const char *prefix, const char *postfix)
 	{
 		int len=0;
-		if (prefix!=NULL) len=strlen(prefix);
-		if (postfix!=NULL) len+=strlen(postfix);
-		char *text=new char[len+1];
-		if (prefix!=NULL)
+		if (prefix != NULL) len = (int)strlen(prefix);
+		if (postfix != NULL) len += (int)strlen(postfix);
+		char *text = new char[len + 1];
+		if (prefix != NULL)
 		{
 			strcpy(text, prefix);
-			if (postfix!=NULL) strcat(text, postfix);
+			if (postfix != NULL) strcat(text, postfix);
 		}
-		else if (postfix!=NULL)
+		else if (postfix != NULL)
 		{
 			strcpy(text, postfix);
 		}
@@ -592,7 +591,6 @@ private:
 		delete[] text;
 		return res;
 	}
-
 };
 
 #endif
