@@ -1,5 +1,5 @@
 /*
-	$Id: inputcursor.h,v 1.5 2001/09/22 15:52:12 plasmoid Exp $
+	$Id: inputcursor.h,v 1.6 2002/05/17 08:47:58 grumbel Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -44,6 +44,10 @@ public:
 	//: Returns the range of the y-coordinate.
 	//- Returns - Max y coordinate value.
 	virtual float get_max_y()=0;
+
+	//: Set the cursor to the position given by x and y
+	virtual void set_position (float x, float y)=0;
+
 };
 
 #endif
