@@ -1,5 +1,5 @@
 /*
-	$Id: checkbox.h,v 1.25 2001/12/27 22:45:46 mbn Exp $
+	$Id: checkbox.h,v 1.28 2002/03/01 13:05:57 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -21,8 +21,6 @@
 
 #include "button.h"
 
-class CL_CheckBox_Generic;
-
 //: CheckBox component
 class CL_CheckBox : public CL_Button
 {
@@ -40,6 +38,12 @@ public:
 		CL_Component *parent,
 		CL_StyleManager *style = NULL);
 
+	//: CheckBox constructor
+	CL_CheckBox(
+		const std::string &text,
+		CL_Component *parent,
+		CL_StyleManager *style = NULL);
+
 	//: CheckBox destructor
 	virtual ~CL_CheckBox();
 
@@ -55,9 +59,7 @@ public:
 
 //! Implementation:
 private:
-	// TODO:Fix this copy constructor:
-	CL_CheckBox(const CL_CheckBox &copy);
-	CL_CheckBox_Generic *impl;
+	CL_CheckBox(const CL_CheckBox &copy) : CL_Button(NULL, NULL) { return; } // disallow copy construction.
 };  
 
 #endif
