@@ -1,5 +1,5 @@
 /*
-	$Id: treeview.h,v 1.15 2001/12/28 00:11:46 sphair Exp $
+	$Id: treeview.h,v 1.18 2002/03/01 22:19:08 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -20,13 +20,12 @@
 #define header_treeview
 
 #include "component.h"
-#include "treeview_node.h"
+#include "treenode.h"
 
 class CL_TreeView_Generic;
-class CL_TreeView;
 
 //: TreeView component
-class CL_TreeView : public CL_Component, public CL_TreeView_Node
+class CL_TreeView : public CL_Component, public CL_TreeNode
 {
 //! Construction:
 public:
@@ -52,11 +51,14 @@ public:
 //! Signals:
 public:
 	//: This signal is emitted when the selection set of a tree changes.
-	CL_Signal_v1<const CL_TreeView_Node &> &sig_selection_changed();
+	CL_Signal_v1<const CL_TreeNode &> &sig_selection_changed();
+
+	//: Draws the node (used by themes).
+	CL_Signal_v2<CL_TreeNode *, CL_Point &> &sig_paint_node();
 
 //! Implementation:
 private:
-//	CL_TreeView(const CL_TreeView &copy) : CL_Component(NULL, NULL) { return; } // disallow copy construction.
+	CL_TreeView(const CL_TreeView &copy) : CL_Component(NULL, NULL), CL_TreeNode(NULL) { return; } // disallow copy construction.
 	CL_TreeView_Generic *impl;
 };
 
