@@ -1,5 +1,5 @@
 /*
-	$Id: application.h,v 1.4 2001/09/16 15:06:38 japj Exp $
+	$Id: application.h,v 1.5 2002/03/01 22:00:15 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -23,4 +23,12 @@
 
 #include "Application/clanapp.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanApp.lib")
+#else
+#pragma comment(lib, "clanAppd.lib")
+#endif
+#endif
+
 #endif
