@@ -1,5 +1,5 @@
 /*
-	$Id: core.h,v 1.39 2002/01/16 16:41:57 mbn Exp $
+	$Id: core.h,v 1.41 2002/03/01 22:00:15 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -23,9 +23,9 @@
 #define header_core
 
 #define CL_VERSION(x,y,z)	( (x << 16) | (y << 8) | (z) )
-#define CL_CURRENT_VERSION	CL_VERSION(0,5,4)
-#define CL_VERSION_STRING "0.5.4"
-#define CL_RELEASE_NAME "Rapid releases here we go"
+#define CL_CURRENT_VERSION	CL_VERSION(0,6,0)
+#define CL_VERSION_STRING "0.6.0"
+#define CL_RELEASE_NAME "When the shit hits the fan"
 
 #ifdef WIN32
 #pragma warning( disable : 4786)
@@ -82,4 +82,13 @@
 #include "Core/Math/size.h"
 #include "Core/Math/point.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanCore.lib")
+#else
+#pragma comment(lib, "clanCored.lib")
+#endif
+#endif
+
+
 #endif
