@@ -1,5 +1,5 @@
 /*
-	$Id: gl.h,v 1.8 2001/12/18 15:55:33 sphair Exp $
+	$Id: gl.h,v 1.9 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -33,4 +33,12 @@
 #include "GL/opengl.h"
 #include "GL/texture.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanGL.lib")
+#else
+#pragma comment(lib, "clanGLd.lib")
+#endif
+#endif
+
 #endif
