@@ -1,5 +1,5 @@
 /*
-	$Id: mikmod.h,v 1.6 2001/12/18 15:55:33 sphair Exp $
+	$Id: mikmod.h,v 1.7 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -27,4 +27,12 @@
 #include "MikMod/setupmikmod.h"
 #include "MikMod/streamed_mikmod_sample.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanMikMod.lib")
+#else
+#pragma comment(lib, "clanMikModd.lib")
+#endif
+#endif
+
 #endif
