@@ -1,5 +1,5 @@
 /*
-	$Id: network.h,v 1.11 2001/12/18 15:55:33 sphair Exp $
+	$Id: network.h,v 1.12 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -45,4 +45,12 @@
 #include "Network/inputsource_socket.h"
 #include "Network/outputsource_socket.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanNetwork.lib")
+#else
+#pragma comment(lib, "clanNetworkd.lib")
+#endif
+#endif
+
 #endif
