@@ -1,5 +1,5 @@
 /*
-	$Id: smalljpeg.h,v 1.3 2001/09/06 18:52:04 japj Exp $
+	$Id: smalljpeg.h,v 1.4 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -18,4 +18,12 @@
 
 #include "SmallJPEG/jpgd_provider.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanSmallJPEG.lib")
+#else
+#pragma comment(lib, "clanSmallJPEGd.lib")
+#endif
+#endif
+
 #endif
