@@ -1,5 +1,5 @@
 /*
-	$Id: sound.h,v 1.7 2001/12/18 15:55:33 sphair Exp $
+	$Id: sound.h,v 1.8 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -43,4 +43,12 @@
 #include "Sound/SoundFilters/inverse_echofilter.h"
 #include "Sound/SoundFilters/fadefilter.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanSound.lib")
+#else
+#pragma comment(lib, "clanSoundd.lib")
+#endif
+#endif
+
 #endif
