@@ -1,5 +1,5 @@
 /*
-	$Id: ttf.h,v 1.5 2001/12/18 15:55:33 sphair Exp $
+	$Id: ttf.h,v 1.6 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -25,4 +25,12 @@
 
 #include "TTF/setupttf.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanTTF.lib")
+#else
+#pragma comment(lib, "clanTTFd.lib")
+#endif
+#endif
+
 #endif
