@@ -1,5 +1,5 @@
 /*
-	$Id: vorbis.h,v 1.6 2001/12/18 15:55:33 sphair Exp $
+	$Id: vorbis.h,v 1.7 2002/03/01 22:00:16 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -29,4 +29,12 @@
 #include "Vorbis/vorbis_soundprovider.h"
 #include "Vorbis/setupvorbis.h"
 
+#if defined (_MSC_VER)
+#if !defined (_DEBUG)
+#pragma comment(lib, "clanVorbis.lib")
+#else
+#pragma comment(lib, "clanVorbisd.lib")
+#endif
+#endif
+
 #endif
