@@ -1,5 +1,5 @@
 /*
-	$Id: datafile_writer.cpp,v 1.9 2001/12/11 20:44:21 mbn Exp $
+	$Id: datafile_writer.cpp,v 1.11 2002/04/06 19:50:45 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -68,11 +68,12 @@ OutputSourceProvider_Datafile::~OutputSourceProvider_Datafile()
 		it != indexes.end();
 		it++)
 	{
-		int name_len = (*it)->name.get_length()+1;
+		short name_len = (*it)->name.get_length()+1;
 		write(datafile_fd, &name_len, sizeof(short));
 		write(datafile_fd, (*it)->name, name_len);
 		write(datafile_fd, &(*it)->pos, sizeof(int));
 		write(datafile_fd, &(*it)->size, sizeof(int));
+		delete *it;
 	}
 
 	lseek(datafile_fd, strlen(datafile_id), SEEK_SET);
