@@ -1,5 +1,5 @@
 /*
-	$Id: datafile_inputprovider.cpp,v 1.15 2001/12/11 20:44:21 mbn Exp $
+	$Id: datafile_inputprovider.cpp,v 1.16 2002/02/28 22:12:56 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -134,6 +134,12 @@ void CL_InputSourceProvider_Datafile::load_resource_ids()
 	}
 }
 
+std::string CL_InputSourceProvider_Datafile::get_path(const std::string &filename)
+{
+	return filename;
+}
+
+
 /**************************
 	CL_InputSource_Datafile
 **************************/
@@ -319,3 +325,4 @@ void CL_InputSource_Datafile::pop_position()
 	if (!compressed) seek(seek_pos, seek_set);
 }
 
+
