@@ -1,5 +1,5 @@
 /*
-	$Id: cl_vector.cpp,v 1.12 2001/12/03 23:00:39 plasmoid Exp $
+	$Id: cl_vector.cpp,v 1.14 2002/06/08 20:50:33 grumbel Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -40,7 +40,7 @@ CL_Vector::CL_Vector(const CL_Vector &other)
 float CL_Vector::norm() const
 {
 	#ifdef WIN32
-	return sqrt(x*x+y*y+z*z);
+	return (float)sqrt(x*x+y*y+z*z);
 	#else
 	return std::sqrt(x*x+y*y+z*z);
 	#endif
@@ -65,7 +65,7 @@ float CL_Vector::dot(const CL_Vector& v) const
 float CL_Vector::angle(const CL_Vector& v) const
 {
 	#ifdef WIN32
-	return acos(dot(v)/(norm()*v.norm()));  
+	return (float)acos(dot(v)/(norm()*v.norm()));  
 	#else
 	return std::acos(dot(v)/(norm()*v.norm()));  
 	#endif
@@ -85,8 +85,8 @@ CL_Vector CL_Vector::rotate(float angle, const CL_Vector& a) const
 	CL_Vector tmp = CL_Vector();
 
 	#ifdef WIN32
-	float s = sin(angle);
-	float c = cos(angle);
+	float s = (float)sin(angle);
+	float c = (float)cos(angle);
 	#else
 	float s = std::sin(angle);
 	float c = std::cos(angle);
@@ -207,7 +207,7 @@ float & CL_Vector::operator [] (int n)
 	return x;			// dummy
 }
 
-std::ostream& operator << (std::ostream& os, CL_Vector& v)
+std::ostream& operator << (std::ostream& os, const CL_Vector& v)
 {
 	os << v.x << " " << v.y << " " << v.z;
 	return os;
