@@ -1,5 +1,5 @@
 /*
-	$Id: resourcetype.cpp,v 1.1.1.1 2000/04/09 12:18:01 mbn Exp $
+	$Id: resourcetype.cpp,v 1.2 2001/04/10 14:24:30 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -13,14 +13,13 @@
 */
 
 #include "Core/precomp.h"
-
 #include <API/Core/Resources/resourcetype.h>
 
 std::list<CL_ResourceType*> CL_ResourceType::resource_types;
 
-CL_ResourceType::CL_ResourceType(std::string _type_id)
+CL_ResourceType::CL_ResourceType(const std::string &type)
+: type(type)
 {
-	type = _type_id;
 	resource_types.push_back(this);
 }
 
