@@ -1,5 +1,5 @@
 /*
-	$Id: app_beos.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: app_beos.h,v 1.2 2000/07/18 17:04:27 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -19,17 +19,16 @@
 #ifndef header_app_beos
 #define header_app_beos
 
-//#define USE_DBG
+#define USE_DBG
 
 #ifdef USE_DBG
+	#include <iostream>
 	#define DBG(x) cout << x << endl
 #else
 	#define DBG(x)
 #endif
 
-#include "API/Core/System/clanapp.h"
-#include "API/Core/System/system.h"
-#include "Core/Display/Be/clanwindowscreen.h"
+class ClanWindowScreen;
 
 #include <Application.h>
 
@@ -38,6 +37,7 @@ class LibApplication : public BApplication
 public:
 	LibApplication();
 	bool is_quitting;
+
 	ClanWindowScreen* clanscreen;
 	
 private:
@@ -49,21 +49,4 @@ private:
 	char** largv;
 };
 
-
-#include "Common/array.h"
-
-class CL_System_KeepAlive;
-
-class CL_System_Generic
-{
-public:
-        static CL_Array<CL_System_KeepAlive> keep_alives;
-};
-
-class CL_System_KeepAlive
-{
-public:
-        virtual bool keep_alive()=0;
-};
-
 #endif
