@@ -1,5 +1,5 @@
 /*
-	$Id: console_window_generic.h,v 1.5 2001/09/08 19:12:44 japj Exp $
+	$Id: console_window_generic.h,v 1.9 2002/02/10 17:03:14 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -16,6 +16,7 @@
 #define header_console_window_generic
 
 #include <string>
+#include <cstdio>
 
 class CL_ConsoleWindow_Generic
 {
@@ -39,6 +40,17 @@ public:
 
 //!Implementation:
 private:
+	void close_file_handles();
+
+#ifdef _MSC_VER
+	FILE *fstdout;
+	FILE *fstdin;
+	FILE *fstderr;
+#else
+	std::FILE *fstdout;
+	std::FILE *fstdin;
+	std::FILE *fstderr;
+#endif
 };
 
 #endif
