@@ -1,5 +1,5 @@
 /*
-	$Id: timer_generic.cpp,v 1.8 2001/09/08 19:12:44 japj Exp $
+	$Id: timer_generic.cpp,v 1.10 2002/01/23 22:51:15 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -32,7 +32,7 @@ void CL_Timer::keep_alive()
 		
 	while (cur >= last_time + interval)
 	{
-		sig_timer();
+		sig_timer()();
 		last_time += interval;
 	}
 }
@@ -64,3 +64,7 @@ unsigned long CL_Timer::get_interval()
 	return interval;
 }
 
+CL_Signal_v0 &CL_Timer::sig_timer()
+{
+	return signal_timer;
+}
