@@ -39,7 +39,7 @@
 \**********************************************************************/
 
 //static const char
-//*cvs_id = "$Id: appconf.cpp,v 1.5 2001/07/03 09:02:01 sphair Exp $";
+//*cvs_id = "$Id: appconf.cpp,v 1.6 2002/01/23 22:32:40 mbn Exp $";
 
 // ============================================================================
 // headers, constants, private declarations
@@ -114,10 +114,11 @@ void LogError(const char *pszFormat, ...)
 
   va_list argptr;
   va_start(argptr, pszFormat);
-  vsprintf(szBuf, pszFormat, argptr);
+  vsnprintf(szBuf, 1023, pszFormat, argptr);
+  szBuf[1023] = 0;
   va_end(argptr);
 
-  strcat(szBuf, "\n");
+  strncat(szBuf, "\n", 1);
   fputs(szBuf, stderr);
 }
 
@@ -1328,7 +1329,8 @@ const char *FileConfig::GlobalConfigFile() const
 
 #ifdef  __unix__
     strcpy(s_szBuf, "/etc/");
-    strcat(s_szBuf, m_szFileName);
+    strncat(s_szBuf, m_szFileName, MAX_PATH - 11); // "/etc/", ".conf", \0
+    s_szBuf[MAX_PATH - 6] = 0;
     if ( bNoExt )
       strcat(s_szBuf, ".conf");
 #else   // Windows
@@ -1348,7 +1350,9 @@ const char *FileConfig::GlobalConfigFile() const
 const char *FileConfig::LocalConfigFile() const
 {
   static char s_szBuf[MAX_PATH];
+  int maxlen;
 
+  maxlen = MAX_PATH - 2 - strlen (m_szFileName) - 7; // "/.", m_szFileName, "/config"
 #ifdef  __unix__
     const char *szHome = getenv("HOME");
     if ( szHome == NULL ) {
@@ -1356,7 +1360,8 @@ const char *FileConfig::LocalConfigFile() const
       LogInfo(_("can't find user's HOME, looking for config file in current directory."));
       szHome = ".";
     }
-    strcpy(s_szBuf, szHome);
+    strncpy(s_szBuf, szHome, maxlen - 1);
+    s_szBuf[maxlen - 1] = 0;
     strcat(s_szBuf, "/.");
     strcat(s_szBuf, m_szFileName);
     if(m_bUseSubDir) // look for ~/.appname/config instead of ~/.appname
@@ -1367,15 +1372,19 @@ const char *FileConfig::LocalConfigFile() const
     }
 #else   // Windows
 #ifdef  __WIN32__
+     maxlen -= 4; // ".INI"
+     int wmaxlen;
       const char *szHome = getenv("HOMEDRIVE");
       if ( szHome == NULL )
         szHome = "";
-      strcpy(s_szBuf, szHome);
+      strncpy(s_szBuf, szHome, maxlen - 1);
+      s_szBuf[maxlen - 1] = 0;
       szHome = getenv("HOMEPATH");
+      wmaxlen = maxlen - 1 - strlen (s_szBuf);
       if ( szHome == NULL )
-        strcpy(s_szBuf, ".");
+        strncpy(s_szBuf, ".", wmaxlen);
       else
-        strcat(s_szBuf, szHome);
+        strncat(s_szBuf, szHome, wmaxlen);
       strcat(s_szBuf, m_szFileName);
       if ( strchr(m_szFileName, '.') == NULL )
         strcat(s_szBuf, ".INI");
