@@ -1,5 +1,5 @@
 /*
-	$Id: mutex_pthread.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: mutex_pthread.h,v 1.2 2001/05/07 17:10:12 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -17,19 +17,9 @@
 
 #include "API/Core/System/mutex.h"
 
-class CL_Mutex_Posix : public CL_Mutex
+class CL_Mutex_Generic
 {
 public:
-	CL_Mutex_Posix();
-	virtual ~CL_Mutex_Posix();
-	
-	virtual void enter();
-	virtual void leave();
-
-	virtual void wait();
-	virtual void notify();
-	virtual void notify_all();
-	
 	pthread_mutex_t mutex;
 	pthread_cond_t cond;
 };
