@@ -1,5 +1,5 @@
 /*
-	$Id: thread_pthread.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: thread_pthread.h,v 1.4 2001/10/11 15:19:56 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -17,20 +17,14 @@
 
 #include "API/Core/System/thread.h"
 
-class CL_Thread_Posix : public CL_Thread
+class CL_Thread_Generic
 {
 public:
-	CL_Thread_Posix(CL_Runnable *runnable);
-	virtual ~CL_Thread_Posix();
-
-	virtual void start();
-	virtual void terminate();
-	virtual void wait();
-
-private:
 	CL_Runnable *runnable;
 	pthread_t thread;
 	bool running;
+	bool delete_runnable;
+	int ref_count;
 
 	static void *run_init(void *self);
 };
