@@ -1,5 +1,5 @@
 /*
-	$Id: init_win32.cpp,v 1.38 2002/01/16 02:00:57 mbn Exp $
+	$Id: init_win32.cpp,v 1.39 2002/05/02 09:00:22 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -135,6 +135,16 @@ LONG WINAPI MainMessageHandler(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lPara
 		}
 		break;
 
+	case WM_SYSCOMMAND:
+		{
+			// Do not allow screensaver to start.
+			if ( wParam != SC_SCREENSAVE )
+			{
+				return DefWindowProc( hWnd, uMsg, wParam, lParam );
+			}
+		}
+		break;
+
 	default:
 		return DefWindowProc(hWnd, uMsg, wParam, lParam);
 	}
