@@ -1,5 +1,5 @@
 /*
-	$Id: thread_win32.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: thread_win32.h,v 1.5 2001/12/19 19:23:03 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -18,23 +18,21 @@
 #include "API/Core/System/thread.h"
 #include <windows.h>
 
-class CL_Thread_Win32 : public CL_Thread
+class CL_Thread_Generic
 {
+//!Attributes:
 public:
-	CL_Thread_Win32(CL_Runnable *runnable);
-	virtual ~CL_Thread_Win32();
-	
-	virtual void start();
-	virtual void terminate();
-	virtual void wait();
-
-private:
 	static unsigned long __stdcall func_proxy(void *arg);
 
 	HANDLE thread_handle;
+
 	DWORD thread_id;
+	
 	CL_Runnable *runnable;
+	
+	bool delete_runnable;
+	
+	int ref_count;
 };
 
 #endif
-
