@@ -1,5 +1,5 @@
 /*
-	$Id: precomp.h,v 1.2 2000/05/09 16:15:50 vogel Exp $
+	$Id: precomp.h,v 1.10 2001/12/14 02:39:57 plasmoid Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -15,21 +15,43 @@
 #ifndef header_precomp
 #define header_precomp
 
-#include "API/stl.h"
 
 #ifdef WIN32
-#include "API/core.h"
+#pragma warning (disable:4786)
 #include <windows.h>
+#include <process.h>
+#include <ddraw.h>
+#include <d3d.h>
+#include <dinput.h>
+#include <dsound.h>
+#include <stdlib.h>
+#include <math.h>
+#include <iostream>
+#include <conio.h>
+#endif
+
+#include "API/signals.h"
+#include "API/Core/System/error.h"
+
+#ifdef __BORLANDC__
+#define BAD_MATH
+#endif
+
+#ifdef BAD_MATH
+#define sqrtf sqrt
+#define acosf acos
+#define sinf sin
+#define cosf cos
+#endif
+
+#ifdef _DEBUG
+#define DEBUG
 #endif
 
 #ifdef WIN32
 #define BREAKPOINT
 #else
-#ifdef __i386
 #define BREAKPOINT asm("int $03");
-#else
-#define BREAKPOINT raise(SIGTRAP);
-#endif
 #endif
 
 #endif
