@@ -1,5 +1,5 @@
 /*
-	$Id: target_generic.cpp,v 1.6 2001/11/28 01:38:14 plasmoid Exp $
+	$Id: target_generic.cpp,v 1.9 2002/02/18 22:47:37 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -301,11 +301,26 @@ void CL_Target::get_pixel(int x, int y, float *r, float *g, float *b, float *a)
 		*a = 1.0f;
 	}
 	else
-	{	
-		*r = (color & get_red_mask()) / (float (get_red_mask()));
-		*g = (color & get_green_mask()) / (float (get_green_mask()));
-		*b = (color & get_blue_mask()) / (float (get_blue_mask()));
-		*a = (color & get_alpha_mask()) / (float (get_alpha_mask()));
+	{
+		unsigned int red_mask = get_red_mask();
+		unsigned int green_mask = get_green_mask();
+		unsigned int blue_mask = get_blue_mask();
+		unsigned int alpha_mask = get_alpha_mask();
+
+		*r = (color & red_mask) / float (red_mask);
+		*g = (color & green_mask) / float (green_mask);
+		*b = (color & blue_mask) / float (blue_mask);
+		
+		// if we have an alphamask, use it
+		if (alpha_mask)
+		{
+			*a = (color & alpha_mask) / float (alpha_mask);
+		}
+		else
+		{
+			//else we have an alpha of 1.0f (don't divide by 0 alpha!)
+			*a = 1.0f;
+		}
 	}
 	unlock();
 }
@@ -718,7 +733,7 @@ void cl_fill_rect_opaque(
 			}
 			else
 			{
-				char color8 = _color;
+				char color8 = (char)_color;
 				if (skip != 0)
 				{
 					for (unsigned int y = 0; y < delta_y; y++)
