@@ -1,5 +1,5 @@
 /*
-	$Id: resource_font_generic.h,v 1.5 2001/09/08 19:12:48 japj Exp $
+	$Id: resource_font_generic.h,v 1.6 2002/03/02 19:43:46 plasmoid Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -16,6 +16,7 @@
 #define header_resource_font_generic
 
 #include "API/Core/Resources/resourcedata.h"
+#include <list>
 
 class CL_Font;
 class CL_Font_Description;
@@ -43,6 +44,7 @@ protected:
 	CL_Slot slot_load_datafile;
 	CL_Slot slot_save_datafile;
 	CL_Slot slot_unload;
+	std::list<class CL_SurfaceProvider*> list_delete;
 };
 
 #endif
