@@ -1,5 +1,5 @@
 /*
-	$Id: displaycard_glx.cpp,v 1.8 2002/01/13 17:49:14 sphair Exp $
+	$Id: displaycard_glx.cpp,v 1.9 2002/02/16 16:10:41 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -361,6 +361,11 @@ void CL_GLX_DisplayCard::keep_alive()
 	}
 }
 
+void (*CL_GLX_DisplayCard::get_proc_address(const std::string& function_name))()
+{
+	return glXGetProcAddressARB((GLubyte*)function_name.c_str());
+}
+
 
 
 #endif
