@@ -1,5 +1,5 @@
 /*
-	$Id: opengl.cpp,v 1.5 2001/03/06 18:51:06 japj Exp $
+	$Id: opengl.cpp,v 1.7 2002/03/05 21:52:14 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -16,6 +16,8 @@
 #include "displaycard_gl_generic.h"
 #include "API/Display/Display/display.h"
 
+#include <string>
+
 void CL_OpenGL::begin_2d()
 {
 	CL_GL_DisplayCard_Generic *card =
@@ -167,3 +169,11 @@ void CL_OpenGL::set_accum_alpha_size(int v)
 	
 	card->set_accum_alpha_size(v);
 }
+
+CL_ProcAddress *CL_OpenGL::get_proc_address(const std::string& function_name)
+{
+	CL_GL_DisplayCard_Generic *card =
+		(CL_GL_DisplayCard_Generic *) CL_Display::get_current_card();
+		
+	return (CL_ProcAddress *) card->get_proc_address(function_name);
+}
