@@ -1,5 +1,5 @@
 /*
-	$Id: texture_gl.cpp,v 1.7 2001/12/11 20:44:22 mbn Exp $
+	$Id: texture_gl.cpp,v 1.8 2002/02/26 22:41:41 sphair Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -131,19 +131,25 @@ void CL_Texture_OpenGL::reload()
 		}
 		
 		glBindTexture(GL_TEXTURE_2D, handles[i]);
-/*	
+	
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
+	
 		glTexImage2D(
 			GL_TEXTURE_2D,
 			0,
-			4,
-			width,
-			height,
+			GL_RGBA,
+			texture_width,
+			texture_height,
 			0,
 			GL_RGBA,
 			GL_UNSIGNED_BYTE,
 			texture_data);
-*/
-		gluBuild2DMipmaps(
+
+/*		gluBuild2DMipmaps(
 			GL_TEXTURE_2D,
 			GL_RGBA,
 			texture_width,
@@ -151,7 +157,7 @@ void CL_Texture_OpenGL::reload()
 			GL_RGBA,
 			GL_UNSIGNED_BYTE,
 			texture_data);
-	}
+*/	}
 
 	delete[] texture_data;
 
