@@ -1,5 +1,5 @@
 /*
-	$Id: displaycard_opengl_win32.cpp,v 1.8 2002/01/07 21:01:20 mbn Exp $
+	$Id: displaycard_opengl_win32.cpp,v 1.10 2002/02/16 16:10:42 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -41,9 +41,11 @@ CL_DisplayCard_OpenGL_Win32::~CL_DisplayCard_OpenGL_Win32()
 {
 	if (!initialized) return;
 	wglDeleteContext(context);
+	ReleaseDC(get_hwnd(), hdc); hdc = NULL;
 	destroy_window();
 
 	if (is_fullscreen()) ChangeDisplaySettings(NULL, 0);
+
 }
 
 void CL_DisplayCard_OpenGL_Win32::flip_display(bool sync)
@@ -135,7 +137,7 @@ void CL_DisplayCard_OpenGL_Win32::set_videomode(
 			0, 0, 0                         // layer masks ignored
 		};
 
-		HDC hdc = GetDC(get_hwnd());
+//		HDC hdc = GetDC(get_hwnd());
 		int pixelformat = ChoosePixelFormat(hdc, &pfd);
 		SetPixelFormat(hdc, pixelformat, &pfd);
 
@@ -166,3 +168,9 @@ void CL_DisplayCard_OpenGL_Win32::set_videomode(
 
 	initialized = true;
 }
+
+void (*CL_DisplayCard_OpenGL_Win32::get_proc_address(const std::string& function_name))()
+{
+	return  (void (*)())wglGetProcAddress(function_name.c_str());
+	
+}
