@@ -1,5 +1,5 @@
 /*
-	$Id: button_generic.h,v 1.18 2001/12/28 13:14:41 sphair Exp $
+	$Id: button_generic.h,v 1.20 2002/02/03 18:03:30 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -26,8 +26,8 @@ public:
 	CL_Button *button;
 
 	void set_options(const CL_ComponentOptions &options);
-	void on_key_down(CL_Component *comp, CL_InputDevice *device, const CL_Key &key);
-	void on_key_up(CL_Component *comp, CL_InputDevice *device, const CL_Key &key);
+	void on_input_down(CL_InputDevice *device, const CL_Key &key);
+	void on_input_up(CL_InputDevice *device, const CL_Key &key);
 	void on_mouse_enter();
 	void on_mouse_leave();
 
@@ -45,11 +45,7 @@ public:
 	CL_Signal_v0 sig_pressed;
 	CL_Signal_v0 sig_released;
 
-	CL_Slot slot_set_options;
-	CL_Slot slot_key_down;
-	CL_Slot slot_key_up;
-	CL_Slot slot_mouse_enter;
-	CL_Slot slot_mouse_leave;
+	CL_SlotContainer slots;
 };  
 
 #endif
