@@ -1,5 +1,5 @@
 /*
-	$Id: checkbox.cpp,v 1.19 2002/01/09 12:59:06 sphair Exp $
+	$Id: checkbox.cpp,v 1.23 2002/03/01 22:19:09 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -13,7 +13,6 @@
 #include "../API/GUI/component.h"
 #include "../API/GUI/component_options.h"
 #include "../API/GUI/stylemanager.h"
-#include "checkbox_generic.h"
 
 /////////////////////////////////////////////////////////////////////////////
 // Construction:
@@ -21,10 +20,22 @@
 CL_CheckBox::CL_CheckBox(
 	CL_Component *parent,
 	CL_StyleManager *style)
-: CL_Button(parent, style), impl(0)
+: CL_Button(parent, style)
 {
-	impl = new CL_CheckBox_Generic(this);
+	set_toggle_mode();
 	get_style_manager()->connect_styles("checkbox", this);
+	find_preferred_size();
+}
+
+CL_CheckBox::CL_CheckBox(
+	const std::string &text,
+	CL_Component *parent,
+	CL_StyleManager *style)
+: CL_Button(text, parent, style)
+{
+	set_toggle_mode();
+	get_style_manager()->connect_styles("checkbox", this);
+	find_preferred_size();
 }
 
 CL_CheckBox::CL_CheckBox(
@@ -32,20 +43,20 @@ CL_CheckBox::CL_CheckBox(
 	const std::string &text,
 	CL_Component *parent,
 	CL_StyleManager *style)
-: CL_Button(pos, text, parent, style), impl(0)
+: CL_Button(pos, text, parent, style)
 {
-	impl = new CL_CheckBox_Generic(this);
+	set_toggle_mode();
 	get_style_manager()->connect_styles("checkbox", this);
 	find_preferred_size();
 }
 
 CL_CheckBox::~CL_CheckBox()
 {
-	delete impl;
 }
 
 /////////////////////////////////////////////////////////////////////////////
 // Attributes:
+
 bool CL_CheckBox::is_checked() const
 {
 	return is_down();
@@ -53,6 +64,7 @@ bool CL_CheckBox::is_checked() const
 
 /////////////////////////////////////////////////////////////////////////////
 // Operations:
+
 void CL_CheckBox::set_checked(bool check)
 {
 	set_down(check);
