@@ -1,5 +1,5 @@
 /*
-	$Id: checkbox_default.h,v 1.17 2002/01/16 18:47:50 sphair Exp $
+	$Id: checkbox_default.h,v 1.18 2002/03/18 13:12:25 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -43,7 +43,8 @@ protected:
 	CL_Font *font;
 	CL_Surface *sur_checked;
 	CL_Surface *sur_unchecked;
-	CL_Surface *sur_disabled;
+	CL_Surface *sur_checked_disabled;
+	CL_Surface *sur_unchecked_disabled;
 };
 
 #endif
