@@ -1,5 +1,5 @@
 /*
-	$Id: popupmenu_default.h,v 1.16 2001/09/08 19:12:52 japj Exp $
+	$Id: popupmenu_default.h,v 1.18 2002/03/01 22:19:09 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -12,29 +12,28 @@
 #define header_popupmenu_default
 
 #include "API/GUI/popupmenu.h"
+#include "API/GUI/stylemanager_default.h"
 #include "API/GUI/component_style.h"
 
-class CL_StyleManager_Default;
-class CL_ResourceManager;
-
 class CL_PopupMenu_Default : public CL_ComponentStyle
 {
 public:
 	CL_PopupMenu_Default(
-		CL_PopupMenu *popupmenu,
-		const CL_ComponentOptions &options,
+		CL_PopupMenu *listbox,
 		CL_StyleManager_Default *style);
-
-	virtual ~CL_PopupMenu_Default() { return; };
+	
+	virtual ~CL_PopupMenu_Default() {};
 
 private:
 	CL_Slot slot_paint;
+	CL_Slot slot_paint_node;
+
 	void on_paint();
+	void on_paint_node(CL_MenuNode *node, CL_Point &point);
 
 	CL_PopupMenu *popupmenu;
-	
+
 	CL_StyleManager_Default *style;
-	CL_ResourceManager *resources;
 };
 
 #endif
