@@ -1,5 +1,5 @@
 /*
-	$Id: popupmenu_generic.h,v 1.8 2001/09/08 19:12:52 japj Exp $
+	$Id: popupmenu_generic.h,v 1.10 2002/03/01 22:19:09 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -15,25 +15,34 @@
 
 class CL_PopupMenu_Generic
 {
+// Construction:
 public:
-	static CL_ComponentOptions create_options(
-		const CL_Point &pos);
-
-	CL_PopupMenu_Generic(CL_PopupMenu *self, const CL_ComponentOptions &options, CL_StyleManager *style);
+	CL_PopupMenu_Generic(CL_PopupMenu *self);
 	~CL_PopupMenu_Generic();
 
 	CL_PopupMenu *popupmenu;
 
+// Attributes:
+public:
+	CL_Component *client_area;
+
+// Signals:
+public:
+	CL_Signal_v1<const CL_MenuNode &> sig_selection_changed;
+	CL_Signal_v2<CL_MenuNode *, CL_Point &> sig_paint_node;
 	CL_Signal_v0 sig_cancelled;
-
+	
+// Slots:
 private:
+	CL_Slot slot_paint_children;
+	CL_Slot slot_resize;
 	CL_Slot slot_lost_focus;
-	CL_Slot slot_child_add;
-	std::list <CL_Slot *> slots_child_click;
 
-	void on_child_add(CL_Component *child);
-	void on_child_click(const CL_Key &key, CL_Component *component);
+// Callbacks:
+private:
+	void on_paint_children(CL_SlotParent_v0 &super);
+	void on_resize(int old_width, int old_height);
 	void on_lost_focus();
-};  
+};
 
 #endif
