@@ -1,5 +1,5 @@
 /*
-	$Id: scrollbar_default.h,v 1.22 2001/12/28 00:17:00 mbn Exp $
+	$Id: scrollbar_default.h,v 1.24 2002/02/01 14:44:06 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -15,7 +15,6 @@
 #include "API/GUI/scrollbar.h"
 #include "API/GUI/stylemanager_default.h"
 #include "API/GUI/component_style.h"
-#include "API/GUI/layout_manager.h"
 
 class CL_ResourceManager;
 class CL_Surface;
@@ -35,20 +34,15 @@ private:
 
 	void on_paint();
 	void on_timer_scroll();
+	void on_resize(int old_width, int old_height);
 
-	CL_Slot slot_paint;
-	CL_Slot slot_increase_pressed;
-	CL_Slot slot_decrease_pressed;
-	CL_Slot slot_increase_released;
-	CL_Slot slot_decrease_released;
-	CL_Slot slot_timer;
+	CL_SlotContainer slots;
 
 	CL_Timer timer_scroll;
 	int scroll_delta;
 
 	CL_ScrollBar *scrollbar;
-	CL_LayoutManager layout;
-
+	
 	CL_Button *button_increase;
 	CL_Button *button_decrease;
 
