@@ -1,5 +1,5 @@
 /*
-	$Id: treeview.cpp,v 1.14 2002/01/04 15:20:43 sphair Exp $
+	$Id: treeview.cpp,v 1.16 2002/03/01 22:19:09 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -23,20 +23,18 @@
 CL_TreeView::CL_TreeView(
 	CL_Component *parent,
 	CL_StyleManager *style)
-: CL_Component(parent, style), CL_TreeView_Node(this), impl(NULL)
+: CL_Component(parent, style), CL_TreeNode(this), impl(NULL)
 {
 	impl = new CL_TreeView_Generic(this);
 	get_style_manager()->connect_styles("treeview", this);
+	find_preferred_size();
 }
 
 CL_TreeView::CL_TreeView(
 	const CL_Rect &pos,
 	CL_Component *parent,
 	CL_StyleManager *style)
-:
-	CL_Component(pos, parent, style),
-	CL_TreeView_Node(this),
-	impl(NULL)
+: CL_Component(pos, parent, style), CL_TreeNode(this), impl(NULL)
 {
 	impl = new CL_TreeView_Generic(this);
 	get_style_manager()->connect_styles("treeview", this);
@@ -58,8 +56,13 @@ CL_Component *CL_TreeView::get_client_area() const
 /////////////////////////////////////////////////////////////////////////////
 // Signals:
 
-CL_Signal_v1<const CL_TreeView_Node &> &CL_TreeView::sig_selection_changed()
+CL_Signal_v1<const CL_TreeNode &> &CL_TreeView::sig_selection_changed()
 {
 	return impl->sig_selection_changed;
 }
 
+CL_Signal_v2<CL_TreeNode *, CL_Point &> &CL_TreeView::sig_paint_node()
+{
+	return impl->sig_paint_node;
+}
+
