@@ -1,5 +1,5 @@
 /*
-	$Id: treeview_default.h,v 1.4 2002/01/16 19:43:06 sphair Exp $
+	$Id: treeview_default.h,v 1.5 2002/03/01 19:36:55 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -26,7 +26,10 @@ public:
 
 private:
 	CL_Slot slot_paint;
+	CL_Slot slot_paint_node;
+
 	void on_paint();
+	void on_paint_node(CL_TreeNode *node, CL_Point &point);
 
 	CL_TreeView *treeview;
 
