@@ -1,5 +1,5 @@
 /*
-	$Id: treeview_generic.h,v 1.9 2002/01/16 19:43:06 sphair Exp $
+	$Id: treeview_generic.h,v 1.10 2002/03/01 19:36:55 sphair Exp $
 	
 	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
 	
@@ -28,7 +28,8 @@ public:
 
 // Signals:
 public:
-	CL_Signal_v1<const CL_TreeView_Node &> sig_selection_changed;
+	CL_Signal_v1<const CL_TreeNode &> sig_selection_changed;
+	CL_Signal_v2<CL_TreeNode *, CL_Point &> sig_paint_node;
 
 // Slots:
 private:
