@@ -1,5 +1,5 @@
 /*
-	$Id: provider_png.cpp,v 1.27 2002/01/22 10:29:33 sphair Exp $
+	$Id: provider_png.cpp,v 1.29 2002/03/23 07:09:26 grumbel Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -421,7 +421,6 @@ void CL_PNGProvider::read_data_palette()
 	png_get_tRNS(png_ptr, info_ptr, &trans, &num_trans, &trans_values);
 	
 	// Setting up the transparent color
-	// FIXME: Can we only support a single transparent color?
 	if (num_trans == 1)
 	{
 		trans_col = trans[0];
@@ -429,11 +428,10 @@ void CL_PNGProvider::read_data_palette()
 	}
 	else if (num_trans > 1)
 	{
-		std::cerr << "CL_PNGProvider: Only one transpranent color is supported" << std::endl;
 		trans_col = trans[0];
 		// We collaps all transparent colors to a single one
 		for (int j = 0; j < pitch * height; j++)
-			for (int i = 1; i < num_trans; i++)
+			for (int i = 0; i < num_trans; i++)
 			{
 				if (trans[i] == image[j])
 					image[j] = trans_col;
