@@ -1,5 +1,5 @@
 /*
-	$Id: sound.cpp,v 1.1 2001/03/06 15:09:26 mbn Exp $
+	$Id: sound.cpp,v 1.2 2002/02/17 00:45:24 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -39,6 +39,16 @@ void CL_Sound::remove_card_preload(CL_SoundCard *card)
 	CL_Sound::preload_cards.remove(card);
 }
 
+CL_StreamSoundProvider *CL_Sound::get_microphone()
+{
+	return get_current_card()->get_microphone();
+}
+
+CL_StreamSoundProvider *CL_Sound::get_line_in()
+{
+	return get_current_card()->get_line_in();
+}
+
 CL_SoundCard *CL_Sound::get_current_card()
 {
 	return cards[0];
