@@ -1,5 +1,5 @@
 /*
-	$Id: inverse_echofilter_generic.cpp,v 1.1 2001/03/06 15:09:26 mbn Exp $
+	$Id: inverse_echofilter_generic.cpp,v 1.2 2002/05/20 12:57:06 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -18,6 +18,9 @@
 
 #include "inverse_echofilter_generic.h"
 #include <memory>
+#ifdef BORLAND
+#include <memory.h>
+#endif
 
 CL_InverseEchoFilter::CL_InverseEchoFilter(int buffer_size)
 {
